==> maven-war-plugin_3.3.2.orig.tar.xz: maven-war-plugin-maven-war-plugin-3.3.2/src/test/java/org/apache/maven/plugins/war/stub/WarArtifact4CCStub.java <==
package org.apache.maven.plugins.war.stub;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.artifact.handler.ArtifactHandler;
import org.apache.maven.artifact.handler.DefaultArtifactHandler;
import org.apache.maven.artifact.versioning.VersionRange;

/**
 * stub for copy constructor
 * to prevent the copy constructor from blowing up
 */
public class WarArtifact4CCStub
    extends WarArtifactStub
{
    public WarArtifact4CCStub( String basedir )
    {
        super( basedir );
    }

    public VersionRange getVersionRange()
    {
        return VersionRange.createFromVersion( getVersion() );
    }

    public String getGroupId()
    {
        return "org.maven.plugin.test";
    }

    public String getClassifier()
    {
        return "testclassifier";
    }

    public ArtifactHandler getArtifactHandler()
    {
        return new DefaultArtifactHandler();
    }
}

==> maven-war-plugin_3.4.0.orig.tar.xz: maven-war-plugin-maven-war-plugin-3.4.0/src/test/java/org/apache/maven/plugins/war/stub/WarArtifact4CCStub.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugins.war.stub;

import org.apache.maven.artifact.handler.ArtifactHandler;
import org.apache.maven.artifact.handler.DefaultArtifactHandler;
import org.apache.maven.artifact.versioning.VersionRange;

/**
 * stub for copy constructor
 * to prevent the copy constructor from blowing up
 */
public class WarArtifact4CCStub extends WarArtifactStub {
    public WarArtifact4CCStub(String basedir) {
        super(basedir);
    }

    public VersionRange getVersionRange() {
        return VersionRange.createFromVersion(getVersion());
    }

    public String getGroupId() {
        return "org.maven.plugin.test";
    }

    public String getClassifier() {
        return "testclassifier";
    }

    public ArtifactHandler getArtifactHandler() {
        return new DefaultArtifactHandler();
    }
}
